==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAngleRepresentation.java <==
// java wrapper for vtkAngleRepresentation object
//

package vtk;
import vtk.*;

public class vtkAngleRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetAngle_2();
  public double GetAngle()
    { return GetAngle_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetCenterWorldPosition_4(double id0[]);
  public void GetCenterWorldPosition(double id0[])
    { GetCenterWorldPosition_4(id0); }

  private native void GetPoint2WorldPosition_5(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_5(id0); }

  private native void SetPoint1DisplayPosition_6(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_6(id0); }

  private native void SetCenterDisplayPosition_7(double id0[]);
  public void SetCenterDisplayPosition(double id0[])
    { SetCenterDisplayPosition_7(id0); }

  private native void SetPoint2DisplayPosition_8(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_8(id0); }

  private native void GetPoint1DisplayPosition_9(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_9(id0); }

  private native void GetCenterDisplayPosition_10(double id0[]);
  public void GetCenterDisplayPosition(double id0[])
    { GetCenterDisplayPosition_10(id0); }

  private native void GetPoint2DisplayPosition_11(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_11(id0); }

  private native void SetHandleRepresentation_12(vtkHandleRepresentation id0);
  public void SetHandleRepresentation(vtkHandleRepresentation id0)
    { SetHandleRepresentation_12(id0); }

  private native void InstantiateHandleRepresentation_13();
  public void InstantiateHandleRepresentation()
    { InstantiateHandleRepresentation_13(); }

  private native long GetPoint1Representation_14();
  public vtkHandleRepresentation GetPoint1Representation() {
    long temp = GetPoint1Representation_14();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetCenterRepresentation_15();
  public vtkHandleRepresentation GetCenterRepresentation() {
    long temp = GetCenterRepresentation_15();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPoint2Representation_16();
  public vtkHandleRepresentation GetPoint2Representation() {
    long temp = GetPoint2Representation_16();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTolerance_17(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_17(id0); }

  private native int GetToleranceMinValue_18();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_18(); }

  private native int GetToleranceMaxValue_19();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_19(); }

  private native int GetTolerance_20();
  public int GetTolerance()
    { return GetTolerance_20(); }

  private native void SetLabelFormat_21(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_21(id0); }

  private native String GetLabelFormat_22();
  public String GetLabelFormat()
    { return GetLabelFormat_22(); }

  private native void SetRay1Visibility_23(int id0);
  public void SetRay1Visibility(int id0)
    { SetRay1Visibility_23(id0); }

  private native int GetRay1Visibility_24();
  public int GetRay1Visibility()
    { return GetRay1Visibility_24(); }

  private native void Ray1VisibilityOn_25();
  public void Ray1VisibilityOn()
    { Ray1VisibilityOn_25(); }

  private native void Ray1VisibilityOff_26();
  public void Ray1VisibilityOff()
    { Ray1VisibilityOff_26(); }

  private native void SetRay2Visibility_27(int id0);
  public void SetRay2Visibility(int id0)
    { SetRay2Visibility_27(id0); }

  private native int GetRay2Visibility_28();
  public int GetRay2Visibility()
    { return GetRay2Visibility_28(); }

  private native void Ray2VisibilityOn_29();
  public void Ray2VisibilityOn()
    { Ray2VisibilityOn_29(); }

  private native void Ray2VisibilityOff_30();
  public void Ray2VisibilityOff()
    { Ray2VisibilityOff_30(); }

  private native void SetArcVisibility_31(int id0);
  public void SetArcVisibility(int id0)
    { SetArcVisibility_31(id0); }

  private native int GetArcVisibility_32();
  public int GetArcVisibility()
    { return GetArcVisibility_32(); }

  private native void ArcVisibilityOn_33();
  public void ArcVisibilityOn()
    { ArcVisibilityOn_33(); }

  private native void ArcVisibilityOff_34();
  public void ArcVisibilityOff()
    { ArcVisibilityOff_34(); }

  private native void BuildRepresentation_35();
  public void BuildRepresentation()
    { BuildRepresentation_35(); }

  private native int ComputeInteractionState_36(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_36(id0,id1,id2); }

  private native void StartWidgetInteraction_37(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_37(id0); }

  private native void CenterWidgetInteraction_38(double id0[]);
  public void CenterWidgetInteraction(double id0[])
    { CenterWidgetInteraction_38(id0); }

  private native void WidgetInteraction_39(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_39(id0); }

  public vtkAngleRepresentation() { super(); }

  public vtkAngleRepresentation(long id) { super(id); }

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkAngleRepresentation.java <==
// java wrapper for vtkAngleRepresentation object
//

package vtk;
import vtk.*;

public class vtkAngleRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetAngle_2();
  public double GetAngle()
    { return GetAngle_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetCenterWorldPosition_4(double id0[]);
  public void GetCenterWorldPosition(double id0[])
    { GetCenterWorldPosition_4(id0); }

  private native void GetPoint2WorldPosition_5(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_5(id0); }

  private native void SetPoint1DisplayPosition_6(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_6(id0); }

  private native void SetCenterDisplayPosition_7(double id0[]);
  public void SetCenterDisplayPosition(double id0[])
    { SetCenterDisplayPosition_7(id0); }

  private native void SetPoint2DisplayPosition_8(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_8(id0); }

  private native void GetPoint1DisplayPosition_9(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_9(id0); }

  private native void GetCenterDisplayPosition_10(double id0[]);
  public void GetCenterDisplayPosition(double id0[])
    { GetCenterDisplayPosition_10(id0); }

  private native void GetPoint2DisplayPosition_11(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_11(id0); }

  private native void SetHandleRepresentation_12(vtkHandleRepresentation id0);
  public void SetHandleRepresentation(vtkHandleRepresentation id0)
    { SetHandleRepresentation_12(id0); }

  private native void InstantiateHandleRepresentation_13();
  public void InstantiateHandleRepresentation()
    { InstantiateHandleRepresentation_13(); }

  private native long GetPoint1Representation_14();
  public vtkHandleRepresentation GetPoint1Representation() {
    long temp = GetPoint1Representation_14();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCenterRepresentation_15();
  public vtkHandleRepresentation GetCenterRepresentation() {
    long temp = GetCenterRepresentation_15();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPoint2Representation_16();
  public vtkHandleRepresentation GetPoint2Representation() {
    long temp = GetPoint2Representation_16();

    if (temp == 0) return null;
    return (vtkHandleRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTolerance_17(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_17(id0); }

  private native int GetToleranceMinValue_18();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_18(); }

  private native int GetToleranceMaxValue_19();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_19(); }

  private native int GetTolerance_20();
  public int GetTolerance()
    { return GetTolerance_20(); }

  private native void SetLabelFormat_21(String id0);
  public void SetLabelFormat(String id0)
    { SetLabelFormat_21(id0); }

  private native String GetLabelFormat_22();
  public String GetLabelFormat()
    { return GetLabelFormat_22(); }

  private native void SetRay1Visibility_23(int id0);
  public void SetRay1Visibility(int id0)
    { SetRay1Visibility_23(id0); }

  private native int GetRay1Visibility_24();
  public int GetRay1Visibility()
    { return GetRay1Visibility_24(); }

  private native void Ray1VisibilityOn_25();
  public void Ray1VisibilityOn()
    { Ray1VisibilityOn_25(); }

  private native void Ray1VisibilityOff_26();
  public void Ray1VisibilityOff()
    { Ray1VisibilityOff_26(); }

  private native void SetRay2Visibility_27(int id0);
  public void SetRay2Visibility(int id0)
    { SetRay2Visibility_27(id0); }

  private native int GetRay2Visibility_28();
  public int GetRay2Visibility()
    { return GetRay2Visibility_28(); }

  private native void Ray2VisibilityOn_29();
  public void Ray2VisibilityOn()
    { Ray2VisibilityOn_29(); }

  private native void Ray2VisibilityOff_30();
  public void Ray2VisibilityOff()
    { Ray2VisibilityOff_30(); }

  private native void SetArcVisibility_31(int id0);
  public void SetArcVisibility(int id0)
    { SetArcVisibility_31(id0); }

  private native int GetArcVisibility_32();
  public int GetArcVisibility()
    { return GetArcVisibility_32(); }

  private native void ArcVisibilityOn_33();
  public void ArcVisibilityOn()
    { ArcVisibilityOn_33(); }

  private native void ArcVisibilityOff_34();
  public void ArcVisibilityOff()
    { ArcVisibilityOff_34(); }

  private native void BuildRepresentation_35();
  public void BuildRepresentation()
    { BuildRepresentation_35(); }

  private native int ComputeInteractionState_36(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_36(id0,id1,id2); }

  private native void StartWidgetInteraction_37(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_37(id0); }

  private native void CenterWidgetInteraction_38(double id0[]);
  public void CenterWidgetInteraction(double id0[])
    { CenterWidgetInteraction_38(id0); }

  private native void WidgetInteraction_39(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_39(id0); }

  public vtkAngleRepresentation() { super(); }

  public vtkAngleRepresentation(long id) { super(id); }

}
